"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PluginOptions = void 0;
const os = require("os");
const typedoc_1 = require("typedoc");
/**
 * Class storing the options of the plugin.
 */
class PluginOptions {
    constructor() {
        /** Plugin option default values. */
        this.defaultValues = {
            type: "detailed",
            location: "local",
            remoteBaseUrl: "http://www.plantuml.com",
            format: "svg",
            sectionTitle: "Hierarchy-Diagram",
            position: "above",
            legendType: "only-included",
            methodParameterOutput: "complete",
            memberOrder: "public-to-private",
            hideEmptyMembers: true,
            topDownLayoutMaxSiblings: 6,
            visibilityStyle: "icon",
            hideCircledChar: false,
            hideShadow: false,
            backgroundColor: "transparent",
            boxBackgroundColor: "",
            boxBorderColor: "",
            boxBorderRadius: 0,
            boxBorderWidth: -1,
            arrowColor: "",
            classFontName: "",
            classFontSize: 0,
            classFontStyle: "normal",
            classFontColor: "",
            attributeFontName: "",
            attributeFontSize: 0,
            attributeFontStyle: "normal",
            attributeFontColor: "",
            generatorProcessCount: os.cpus().length,
            hideProgressBar: false,
            createPlantUmlFiles: false,
            verboseOutput: false,
        };
    }
    /**
     * Returns how detailed the generated class diagrams should be.
     * @returns How detailed the generated class diagrams should be.
     */
    get type() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.type) !== null && _b !== void 0 ? _b : this.defaultValues.type;
    }
    /**
     * Returns the location where the class diagrams should be stored.
     * @returns The location where the class diagrams should be stored.
     */
    get location() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.location) !== null && _b !== void 0 ? _b : this.defaultValues.location;
    }
    /**
     * Returns the base URL used when generating remote images.
     * @returns The base URL used when generating remote images.
     */
    get remoteBaseUrl() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.remoteBaseUrl) !== null && _b !== void 0 ? _b : this.defaultValues.remoteBaseUrl;
    }
    /**
     * Returns the image format used for the class diagrams.
     * @returns The image format used for the class diagrams.
     */
    get format() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.format) !== null && _b !== void 0 ? _b : this.defaultValues.format;
    }
    /**
     * Returns the title that should be used for the section that contains the class diagrams.
     * @returns The title that should be used for the section that contains the class diagrams.
     */
    get sectionTitle() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.sectionTitle) !== null && _b !== void 0 ? _b : this.defaultValues.sectionTitle;
    }
    /**
     * Returns where on the page the class diagrams should be put.
     * @returns Where on the page the class diagrams should be put.
     */
    get position() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.position) !== null && _b !== void 0 ? _b : this.defaultValues.position;
    }
    /**
     * Returns the type of legend that should be generated for the class diagrams.
     * @returns The type of legend that should be generated for the class diagrams.
     */
    get legendType() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.legendType) !== null && _b !== void 0 ? _b : this.defaultValues.legendType;
    }
    /**
     * Returns how method parameters should be output in the class diagrams.
     * @returns How method parameters should be output in the class diagrams.
     */
    get methodParameterOutput() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.methodParameterOutput) !== null && _b !== void 0 ? _b : this.defaultValues.methodParameterOutput;
    }
    /**
     * Returns how class members should be ordered in the class diagrams.
     * @returns How class members should be ordered the class diagrams.
     */
    get memberOrder() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.memberOrder) !== null && _b !== void 0 ? _b : this.defaultValues.memberOrder;
    }
    /**
     * Returns whether to hide empty properties and methods in the class diagrams.
     * @returns Whether to hide empty properties and methods in the class diagrams.
     */
    get hideEmptyMembers() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.hideEmptyMembers) !== null && _b !== void 0 ? _b : this.defaultValues.hideEmptyMembers;
    }
    /**
     * Returns the boundary before swiching from top->down to left->right direction for class diagrams.
     * @returns The boundary before swiching from top->down to left->right direction for class diagrams.
     */
    get topDownLayoutMaxSiblings() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.topDownLayoutMaxSiblings) !== null && _b !== void 0 ? _b : this.defaultValues.topDownLayoutMaxSiblings;
    }
    /**
     * Returns how the member visibility is rendered in the class diagrams.
     * @returns How the member visibility is rendered in the class diagrams.
     */
    get visibilityStyle() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.visibilityStyle) !== null && _b !== void 0 ? _b : this.defaultValues.visibilityStyle;
    }
    /**
     * Returns whether to hide the circled character in front of class names for class diagrams.
     * @returns Whether to hide the circled character in front of class names for class diagrams.
     */
    get hideCircledChar() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.hideCircledChar) !== null && _b !== void 0 ? _b : this.defaultValues.hideCircledChar;
    }
    /**
     * Returns whether to hide the shadows in the class diagrams.
     * @returns Whether to hide the shadows in the class diagrams.
     */
    get hideShadow() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.hideShadow) !== null && _b !== void 0 ? _b : this.defaultValues.hideShadow;
    }
    /**
     * Returns the color that should be used for the background of all class diagrams.
     * @returns The color that should be used for the background of all class diagrams.
     */
    get backgroundColor() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.backgroundColor) !== null && _b !== void 0 ? _b : this.defaultValues.backgroundColor;
    }
    /**
     * Returns the background color that should be used for boxes in the class diagrams.
     * @returns The background color that should be used for boxes in the class diagrams.
     *          An empty string if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get boxBackgroundColor() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.boxBackgroundColor) !== null && _b !== void 0 ? _b : this.defaultValues.boxBackgroundColor;
    }
    /**
     * Returns the border color that should be used for boxes in the class diagrams.
     * @returns The border color that should be used for boxes in the class diagrams.
     *          An empty string if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get boxBorderColor() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.boxBorderColor) !== null && _b !== void 0 ? _b : this.defaultValues.boxBorderColor;
    }
    /**
     * Returns the border radius that should be used for boxes in the class diagrams.
     * @returns The border radius that should be used for boxes in the class diagrams.
     */
    get boxBorderRadius() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.boxBorderRadius) !== null && _b !== void 0 ? _b : this.defaultValues.boxBorderRadius;
    }
    /**
     * Returns the border width that should be used for boxes in the class diagrams.
     * @returns The border width that should be used for boxes in the class diagrams.
     *          The value -1 if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get boxBorderWidth() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.boxBorderWidth) !== null && _b !== void 0 ? _b : this.defaultValues.boxBorderWidth;
    }
    /**
     * Returns the color that should be used for arrows in the class diagrams.
     * @returns The color that should be used for arrows in the class diagrams.
     *          An empty string if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get arrowColor() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.arrowColor) !== null && _b !== void 0 ? _b : this.defaultValues.arrowColor;
    }
    /**
     * Returns the name of the font that should be used for the class name in the class diagrams.
     * @returns The name of the font that should be used for the class name in the class diagrams.
     *          An empty string if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get classFontName() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.classFontName) !== null && _b !== void 0 ? _b : this.defaultValues.classFontName;
    }
    /**
     * Returns the font size that should be used for class names in the class diagrams.
     * @returns The font size that should be used for class names in the class diagrams.
     *          The value 0 if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get classFontSize() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.classFontSize) !== null && _b !== void 0 ? _b : this.defaultValues.classFontSize;
    }
    /**
     * Returns the font style that should be used for the class name in the class diagrams.
     * @returns The font style that should be used for the class name in the class diagrams.
     */
    get classFontStyle() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.classFontStyle) !== null && _b !== void 0 ? _b : this.defaultValues.classFontStyle;
    }
    /**
     * Returns the font color that should be used for the class name in the class diagrams.
     * @returns The font color that should be used for the class name in the class diagrams.
     *          An empty string if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get classFontColor() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.classFontColor) !== null && _b !== void 0 ? _b : this.defaultValues.classFontColor;
    }
    /**
     * Returns the name of the font that should be used for class attributes in the class diagrams.
     * @returns The name of the font that should be used for class attributes in the class diagrams.
     *          An empty string if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get attributeFontName() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.attributeFontName) !== null && _b !== void 0 ? _b : this.defaultValues.attributeFontName;
    }
    /**
     * Returns the font size that should be used for class attributes in the class diagrams.
     * @returns The font size that should be used for class attributes in the class diagrams.
     *          The value 0 if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get attributeFontSize() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.attributeFontSize) !== null && _b !== void 0 ? _b : this.defaultValues.attributeFontSize;
    }
    /**
     * Returns the font style that should be used for the class attributes in the class diagrams.
     * @returns The font style that should be used for the class attributes in the class diagrams.
     */
    get attributeFontStyle() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.attributeFontStyle) !== null && _b !== void 0 ? _b : this.defaultValues.attributeFontStyle;
    }
    /**
     * Returns the font color that should be used for the class attributes in the class diagrams.
     * @returns The font color that should be used for the class attributes in the class diagrams.
     *          An empty string if no value was specified by the caller.
     *          In this case the PlantUML default value should be used.
     */
    get attributeFontColor() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.attributeFontColor) !== null && _b !== void 0 ? _b : this.defaultValues.attributeFontColor;
    }
    /**
     * Returns the number of PlantUML processes that should be used for generating the class diagrams.
     * @returns The number of PlantUML processes that should be used for generating the class diagrams.
     */
    get generatorProcessCount() {
        var _a, _b;
        const processCount = (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.generatorProcessCount) !== null && _b !== void 0 ? _b : -1;
        return processCount <= 0 ? this.defaultValues.generatorProcessCount : processCount;
    }
    /**
     * Returns whether to hide the progress bar while generating the class diagrams.
     * @returns True, if the progress bar should not be displayed while generating the class diagrams, otherwise false.
     */
    get hideProgressBar() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.hideProgressBar) !== null && _b !== void 0 ? _b : this.defaultValues.hideProgressBar;
    }
    /**
     * Returns whether to create files containing the PlantUML code for the class diagrams.
     * @returns True, if files with the PlantUML code should be created, otherwise false.
     */
    get createPlantUmlFiles() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.createPlantUmlFiles) !== null && _b !== void 0 ? _b : this.defaultValues.createPlantUmlFiles;
    }
    /**
     * Returns whether the plugin should output verbose info during its work.
     * @returns True, if plugin should create verbose output, otherwise false.
     */
    get createVerboseOutput() {
        var _a, _b;
        return (_b = (_a = this.userValues) === null || _a === void 0 ? void 0 : _a.verboseOutput) !== null && _b !== void 0 ? _b : this.defaultValues.verboseOutput;
    }
    /**
     * Adds the command line options of the plugin to the TypeDoc application.
     * @param typedoc The TypeDoc application.
     */
    // eslint-disable-next-line class-methods-use-this
    addToApplication(typedoc) {
        typedoc.options.addDeclaration({
            type: typedoc_1.ParameterType.Mixed,
            name: "umlClassDiagram",
            help: "The object defining the options of the typedoc-umlclass plugin.",
        });
    }
    /**
     * Reads the values of the plugin options from the application options.
     * @param typedoc The TypeDoc application.
     */
    readValuesFromApplication(typedoc) {
        this.userValues = typedoc.options.getValue("umlClassDiagram");
    }
}
exports.PluginOptions = PluginOptions;
