"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.privateToPublic = exports.publicToPrivate = exports.nameAbc = void 0;
/**
 * Compare function for sorting reflections by their name alphabetically.
 * @param a First reflection.
 * @param b Second reflection.
 * @returns -1 if (a < b), 0 if (a === b) or 1 if (a > b).
 */
const nameAbc = (a, b) => {
    const aName = a.name.toUpperCase();
    const bName = b.name.toUpperCase();
    if (aName < bName) {
        return -1;
    }
    else if (aName > bName) {
        return 1;
    }
    return 0;
};
exports.nameAbc = nameAbc;
/**
 * Compare function for sorting reflections by their visibility (public to private).
 * @param a First reflection.
 * @param b Second reflection.
 * @returns -1 if (a < b), 0 if (a === b) or 1 if (a > b).
 */
const publicToPrivate = (a, b) => {
    if (a.flags.isProtected) {
        if (b.flags.isProtected) {
            return (0, exports.nameAbc)(a, b);
        }
        else if (b.flags.isPrivate) {
            return -1;
        }
        return 1;
    }
    else if (a.flags.isPrivate) {
        if (b.flags.isProtected) {
            return 1;
        }
        else if (b.flags.isPrivate) {
            return (0, exports.nameAbc)(a, b);
        }
        return 1;
    }
    if (b.flags.isProtected) {
        return -1;
    }
    else if (b.flags.isPrivate) {
        return -1;
    }
    return (0, exports.nameAbc)(a, b);
};
exports.publicToPrivate = publicToPrivate;
/**
 * Compare function for sorting reflections by their visibility (private to public).
 * @param a First reflection.
 * @param b Second reflection.
 * @returns -1 if (a < b), 0 if (a === b) or 1 if (a > b).
 */
const privateToPublic = (a, b) => {
    if (a.flags.isProtected) {
        if (b.flags.isProtected) {
            return (0, exports.nameAbc)(a, b);
        }
        else if (b.flags.isPrivate) {
            return 1;
        }
        return -1;
    }
    else if (a.flags.isPrivate) {
        if (b.flags.isProtected) {
            return -1;
        }
        else if (b.flags.isPrivate) {
            return (0, exports.nameAbc)(a, b);
        }
        return -1;
    }
    if (b.flags.isProtected) {
        return 1;
    }
    else if (b.flags.isPrivate) {
        return 1;
    }
    return (0, exports.nameAbc)(a, b);
};
exports.privateToPublic = privateToPublic;
